#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 linear
version:              1.23.3
visibility:           public
id:                   linear-1.23.3-2aBP1l9fwUjkhzM5Lv6oi
key:                  linear-1.23.3-2aBP1l9fwUjkhzM5Lv6oi
license:              BSD-3-Clause
copyright:            Copyright (C) 2012-2015 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/linear/
synopsis:             Linear Algebra
description:
    Types and combinators for linear algebra on free vector spaces

category:             Math, Algebra
abi:                  9bc7aada34f5eaea0d3f29572290759a
exposed:              True
exposed-modules:
    Linear Linear.Affine Linear.Algebra Linear.Binary Linear.Conjugate
    Linear.Covector Linear.Epsilon Linear.Instances Linear.Matrix
    Linear.Metric Linear.Plucker Linear.Plucker.Coincides
    Linear.Projection Linear.Quaternion Linear.Trace Linear.V Linear.V0
    Linear.V1 Linear.V2 Linear.V3 Linear.V4 Linear.Vector

import-dirs:          /usr/lib/ghc-9.6.6/site-local/linear-1.23.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/linear-1.23.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/linear-1.23.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-linear
hs-libraries:         HSlinear-1.23.3-2aBP1l9fwUjkhzM5Lv6oi
depends:
    adjunctions-4.4.4-71tDgq3IqjJJp4SDYlRIo1 base-4.18.2.1
    base-orphans-0.9.3-4aYU8kUnH3JJ5hhvXSRw2I binary-0.8.9.1
    bytes-0.17.5-9D0uR6pSl9M6hj9evFst1u
    cereal-0.5.8.3-9zr3eQnzv374L09nXO1NoK containers-0.6.7
    deepseq-1.4.8.1 distributive-0.6.2.1-Gy5IBIr3XJgGPXyO18mHVS
    hashable-1.4.7.0-JuZCUcgZ6993MAquoa2cCW
    indexed-traversable-0.1.4-8j5HZpShpE5BqFup9Ojenr
    lens-5.3.4-AArhojR1bHQDPd0CW0dSET
    random-1.2.1.3-Gsn6cRa5LQY7Fg5vZFQhOU
    reflection-2.1.9-If5VWiZqt62BWh8XS2ZR33
    semigroupoids-6.0.2-5KpCoZ3FBsyCetKjS7KKeX
    template-haskell-2.20.0.0 transformers-0.6.1.0
    unordered-containers-0.2.20.1-24qNbjJ9xXJll0vtFCYfq
    vector-0.13.2.0-5hQDxYlIzjI43Z4IxwIpHc

haddock-interfaces:   /usr/share/doc/haskell-linear/html/linear.haddock
haddock-html:         /usr/share/doc/haskell-linear/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

